#
# spec file for package ghc-vty
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name vty
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        5.33
Release:        1.4
Summary:        A simple terminal UI library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-microlens-devel
BuildRequires:  ghc-microlens-mtl-devel
BuildRequires:  ghc-microlens-th-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-parallel-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-terminfo-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-quickcheck-assertions-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-smallcheck-devel
BuildRequires:  ghc-string-qq-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-smallcheck-devel
%endif

%description
Vty is terminal GUI library in the niche of ncurses. It is intended to be easy
to use, have no confusing corner cases, and good support for common terminal
types.

See the 'vty-examples' package as well as the program
'test/interactive_terminal_test.hs' included in the 'vty' package for examples
on how to use the library.

Import the "Graphics.Vty" convenience module to get access to the core parts of
the library.

&#169; 2006-2007 Stefan O'Rear; BSD3 license.

&#169; Corey O'Connor; BSD3 license.

&#169; Jonathan Daugherty; BSD3 license.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/vty-build-width-table
%{_bindir}/vty-demo
%{_bindir}/vty-mode-demo

%files devel -f %{name}-devel.files
%doc AUTHORS CHANGELOG.md README.md

%changelog
* Wed Feb 24 2021 psimons@suse.com
- Update vty to version 5.33 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Feb 23 2021 psimons@suse.com
- Update vty to version 5.33.
  5.33
  - ---
  API changes:
  * The `Cursor` type got a new `PositionOnly` constructor for cursor
    placement without visibility.
  Package changes:
  * Relaxed upper bound for `random`
  * Updated `microlens` bounds to allow 0.4.12
  Other improvements:
  * Various hlint-driven improvements (thanks Willem Van Onsem)
  * The implementation of `color240` was improved (thanks (Willem Van
    Onsem)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Nov 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
-  relax overspecified constraints on microlens
* Mon Nov  9 2020 psimons@suse.com
- Update vty to version 5.32.
  5.32
  - ---
  New features:
  * Meta-PageUp and Meta-PageDown are now supported (#193)
  * Added `supportsItalics` and `supportsStrikethrough` functions to
    check for feature support in terminfo
  Bug fixes:
  * Detect utf-8 mode in `LANG` regardless of case (thanks Emeka
    Nkurumeh)
* Tue Oct  6 2020 psimons@suse.com
- Update vty to version 5.31.
  5.31
  - ---
  New features and API changes:
  * Added support for strikethrough mode. This change adds a new
    `strikethrough` `Style` value and uses the `smxx` and `rmxx`
    Terminfo capabilities to activate and deactivate strikethrough mode,
    respectively. If the terminfo does not report those capabilities,
    this style is ignored.
  * `Output`: added the `setDisplayBounds` field to set the output
    dimensions of the output handle; added an implementation of this for
    the `TerminfoBased` backend.
  Other changes:
  * The C prototype for `vty_c_get_window_size` in `gwinsz.h` was fixed.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu Jul 16 2020 psimons@suse.com
- Update vty to version 5.30.
  5.30
  - ---
  New features:
  * Added `Graphics.Vty.setWindowTitle` to emit an escape
    sequence to set the window title, provide the terminal emulator
    accepts Xterm-style title sequences. For details, see:
    https://tldp.org/HOWTO/Xterm-Title-3.html
* Fri Jul 10 2020 psimons@suse.com
- Update vty to version 5.29.
  5.29
  - ---
  API changes:
  * The Input type got a new field, 'restoreInputState'. This field
    allows the end user to have direct access to the logic needed to
    restore the terminal's input state flags. Prior to having this field,
    this state restoration logic could only be invoked as part of calling
    'shutdownInput', but since that function does other things (like
    killing threads) it is not advisable to call it repeatedly (which is
    necessary in the use case this change is intended to support). This
    can be called directly to restore the input state flags as needed,
    although this is not required if 'shutdown' (or 'shutdownInput') is
    called.
  Other changes:
  * attributeControl: explicitly enable the ICRNL terminal mode flag (see
    [#187] and c572ad).
* Tue Jun  9 2020 psimons@suse.com
- Add vty at version 5.28.2.
